PcapFileHeader

Struct PcapFileHeader 

pub struct PcapFileHeader {
    pub magic_number_and_endianness: MagicNumberAndEndianness,
    pub version: Version,
    pub timezone: u32,
    pub sig_figs: u32,
    pub snap_length: u32,
    pub link_type: LinkType,
}
Represents the file header of a pcap file

Fields

magic_number_and_endianness: MagicNumberAndEndianness

First 4 bytes are the magic number and endianness

version: Version

The version of the pcap file format Bytes 4..8

timezone: u32

The timezone offset Bytes 8..12

sig_figs: u32

The number of significant figures Bytes 12..16

snap_length: u32

The maximum byte length of captured packets

Bytes 16..20

link_type: LinkType

The link type of the captured packets Bytes 20..24

Implementations

Source

impl PcapFileHeader

pub fn read<R: Read>(reader: &mut R) -> Result<Self, PcapParseError>

Reads the file header from the reader

pub fn write<W: Write>(&self, writer: &mut W) -> Result<(), Error>

Writes the file header to the writer