PacketHeader

Struct PacketHeader 

pub struct PacketHeader {
    pub timestamp: PacketTimestamp,
    pub include_len: u32,
    pub orig_len: u32,
}

Fields

timestamp: PacketTimestampinclude_len: u32

The length of the packet data included in the file

orig_len: u32

The original length of the packet data

Implementations

Source

impl PacketHeader

pub fn new(timestamp: PacketTimestamp, incl_len: u32, orig_len: u32) -> Self

pub fn read<R: Read>( reader: &mut R, endianness: Endianness, version: &Version, ) -> Result<Self, PcapParseError>

Reads the packet header from the reader Returns Ok(Self) on success, or Err if there was an error reading the packet header The endianness is used to determine how to read the bytes

pub fn parse_bytes( bytes: &[u8; 16], endianness: Endianness, version: &Version, ) -> Result<Self, PcapParseError>

pub fn write<W: Write>( &self, writer: &mut W, endianness: Endianness, version: &Version, ) -> Result<(), Error>