pub struct SyncPcapReader<R: Read> { /* private fields */ }Implementations
Sourceimpl<R: Read> SyncPcapReader<R>
impl<R: Read> SyncPcapReader<R>
Sourcepub fn new(reader: R) -> Result<Self, PcapParseError>
pub fn new(reader: R) -> Result<Self, PcapParseError>
Creates a new SyncPcapReader from a reader
Returns Ok(Self) on success, or Err if there was an error
reading the file header
A buffer is allocated based on the snap length in the file header
Sourcepub fn file_header(&self) -> &PcapFileHeader
pub fn file_header(&self) -> &PcapFileHeader
Returns the file header of the pcap file
pub fn next_packet( &mut self, ) -> Result<Option<(PacketHeader, &[u8])>, PcapParseError>