AsyncPcapReader

Struct AsyncPcapReader 

pub struct AsyncPcapReader<R: AsyncRead + Unpin> { /* private fields */ }

Implementations

Source

impl<R: AsyncRead + Unpin> AsyncPcapReader<R>

pub async fn new(reader: R) -> Result<Self, PcapParseError>

Creates a new AsyncPcapReader from a reader Returns Ok(Self) on success, or Err if there was an error reading the file header

A buffer is allocated based on the snap length in the file header

pub fn file_header(&self) -> &PcapFileHeader

Returns the file header of the pcap file

pub async fn next_packet( &mut self, ) -> Result<Option<(PacketHeader, &[u8])>, PcapParseError>

Reads the next packet from the pcap file Returns Ok(None) if there are no more packets to read Returns Err if there was an error reading the packet