pub enum InterfaceOptionCodes {
Show 16 variants
IfName = 2,
IfDescription = 3,
IfIPv4Address = 4,
IfIPv6Address = 5,
IfMACAddress = 6,
IfEuiAddr = 7,
IfSpeed = 8,
IfTimestampResolution = 9,
IfTZone = 10,
IfFilter = 11,
IfOS = 12,
IfFcsLength = 13,
IfTsOffset = 14,
IfHardware = 15,
IfTxSpeed = 16,
IfRxSpeed = 17,
}Expand description
Options for the Interface Description Block
Variants
IfName = 2
The if_name option is a UTF-8 string containing the name of the device used to capture data. The string is not zero-terminated.
IfDescription = 3
The if_description option is a UTF-8 string containing the description of the device used to capture data. The string is not zero-terminated.
IfIPv4Address = 4
IfIPv6Address = 5
IfMACAddress = 6
IfEuiAddr = 7
IfSpeed = 8
The if_speed option is a 64-bit unsigned value indicating the interface speed, in bits per second.
IfTimestampResolution = 9
IfTZone = 10
IfFilter = 11
IfOS = 12
IfFcsLength = 13
IfTsOffset = 14
IfHardware = 15
IfTxSpeed = 16
IfRxSpeed = 17