BlockOption

Struct BlockOption 

pub struct BlockOption {
    pub code: u16,
    pub length: u16,
    pub pen: Option<u32>,
    pub value: Vec<u8>,
}

Fields

code: u16

Option code

length: u16

Length of the option value in bytes

pen: Option<u32>

Private Enterprise Number (PEN)

Only present if the option is a custom option

value: Vec<u8>

The value of the option

Implementations

Source

impl BlockOption

pub fn new( option_code: u16, pen: Option<u32>, option_value: impl Into<Vec<u8>>, ) -> Result<Self, InvalidOption>

Creates a new BlockOption

Pen can only be set if the option code is a custom option.

pub fn padding_length(&self) -> usize