pub struct PcapFileHeader {
pub magic_number_and_endianness: MagicNumberAndEndianness,
pub version: Version,
pub timezone: u32,
pub sig_figs: u32,
pub snap_length: u32,
pub link_type: LinkType,
}Expand description
Represents the file header of a pcap file
Fields
magic_number_and_endianness: MagicNumberAndEndiannessFirst 4 bytes are the magic number and endianness
version: VersionThe version of the pcap file format Bytes 4..8
timezone: u32The timezone offset Bytes 8..12
sig_figs: u32The number of significant figures Bytes 12..16
snap_length: u32The maximum byte length of captured packets
Bytes 16..20
link_type: LinkTypeThe link type of the captured packets Bytes 20..24
Implementations