pub struct GenericBlock {
pub block_id: u32,
pub block_length: u32,
pub data: Option<Vec<u8>>,
}Expand description
A Generic Block in the PCAP-NG format
Used for unknown block ids or custom blocks that do not have a specific structure defined in the PCAP-NG specification.
Fields
block_id: u32The block ID
block_length: u32The length of the block in bytes, including the header
data: Option<Vec<u8>>The data of the block, if any
Implementations
Sourceimpl GenericBlock
impl GenericBlock
pub fn new(block_id: u32, data: Option<Vec<u8>>) -> Self
pub fn read_with_header<R: Read>( reader: &mut R, header: &BlockHeader, byte_order: Endianness, ) -> Result<Self, PcapNgParseError>
pub fn read<R: Read>( reader: &mut R, byte_order: Endianness, ) -> Result<Self, PcapNgParseError>